function createScatterPlot({
  containerSelector,
  dataUrl,
  title,
  colorAboveMedian = '#69b3a2', // Color for values above or equal to the median
  colorBelowMedian = 'red', // Color for values below the median
  symbolType = d3.symbolTriangle, // Using triangle symbol
}) {
  d3.csv(dataUrl).then((data) => {
    data.forEach((d) => {
      d.Age = +d.Age;
      d.Salary = +d.Salary;
    });

    // Calculate median salary
    const salaries = data
      .map((d) => d.Salary)
      .sort((a, b) => a - b);
    const medianSalary = d3.median(salaries);

    const margin = {
        top: 50,
        right: 50,
        bottom: 70,
        left: 70,
      },
      width = 960 - margin.left - margin.right,
      height = 800 - margin.top - margin.bottom;

    const svg = d3
      .select(containerSelector)
      .append('svg')
      .attr('width', width + margin.left + margin.right)
      .attr('height', height + margin.top + margin.bottom)
      .append('g')
      .attr(
        'transform',
        `translate(${margin.left},${margin.top})`,
      );

    if (title) {
      svg
        .append('text')
        .attr('x', width / 2)
        .attr('y', 0 - margin.top / 2)
        .attr('text-anchor', 'middle')
        .style('font-size', '24px')
        .style('text-decoration', 'underline')
        .text(title);
    }

    const x = d3
      .scaleLinear()
      .domain([0, d3.max(data, (d) => d.Age)])
      .range([0, width]);
    svg
      .append('g')
      .attr('transform', `translate(0,${height})`)
      .call(d3.axisBottom(x));

    svg
      .append('text')
      .attr(
        'transform',
        `translate(${width / 2}, ${height + margin.top + 20})`,
      )
      .style('text-anchor', 'middle')
      .text('Age');

    const y = d3
      .scaleLinear()
      .domain([0, d3.max(data, (d) => d.Salary)])
      .range([height, 0]);
    svg.append('g').call(d3.axisLeft(y));

    svg
      .append('text')
      .attr('transform', 'rotate(-90)')
      .attr('y', 0 - margin.left)
      .attr('x', 0 - height / 2)
      .attr('dy', '1em')
      .style('text-anchor', 'middle')
      .text('Salary');

    svg
      .selectAll('.symbol')
      .data(data)
      .enter()
      .append('path')
      .attr('class', 'symbol')
      .attr('d', d3.symbol().size(64).type(symbolType))
      .attr(
        'transform',
        (d) => `translate(${x(d.Age)},${y(d.Salary)})`,
      )
      .style('fill', (d) =>
        d.Salary >= medianSalary
          ? colorAboveMedian
          : colorBelowMedian,
      );
  });
}

// Example usage with triangle symbols
createScatterPlot({
  containerSelector: 'body',
  dataUrl:
    'https://gist.githubusercontent.com/VarshaYarragunta/2c12648151358d5d8086acfba2cf0b16/raw/10e6007cfdfca35feb51ac076163ee41bfe6869b/Salary.csv',
  title: 'Age vs. Salary Scatter Plot',
  colorAboveMedian: '#007bff', // Example color
  colorBelowMedian: '#28a745', // Another example color
  symbolType: d3.symbolTriangle, // Now using triangles
});
